#
# spec file for package FlightGear
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define main_version 2020.3
Name:           FlightGear
Version:        %{main_version}.18
Release:        1.2
Summary:        Flight Simulator
License:        GPL-2.0-only
Group:          Amusements/Games/3D/Simulation
URL:            https://www.flightgear.org/
Source0:        https://sourceforge.net/projects/flightgear/files/release-%{main_version}/flightgear-%{version}.tar.bz2

BuildRequires:  SimGear-devel = %{version}
BuildRequires:  cmake
BuildRequires:  freeglut-devel
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libboost_headers-devel
BuildRequires:  libevent-devel
BuildRequires:  pkgconfig
BuildRequires:  plib-devel
BuildRequires:  sqlite3-devel
BuildRequires:  update-desktop-files
# Required for screensaver inhibition
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(speex)
BuildRequires:  pkgconfig(speexdsp)

# Additional dependencies to enable FlightGear's new Qt launcher interface
BuildRequires:  libQt5PlatformHeaders-devel
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Qml)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Widgets)
# If not installed, FG downloads the data on launch
Recommends:     FlightGear-data = %{version}

%description
The FlightGear project is working to create a sophisticated flight
simulator framework for the development and pursuit of interesting
flight simulator ideas. We are developing a solid basic sim that can be
expanded and improved upon by anyone interested in contributing

%prep
%setup -q -n flightgear-%{version}

# remove some unneeded doc files
for ext in Cygwin IRIX Joystick Linux MSVC MSVC8 MacOS SimGear Unix Win32-X autoconf mingw plib src xmlsyntax; do
  rm -f docs-mini/README.${ext}
done

%build
%cmake \
    -DFG_DATA_DIR:STRING="%{_datadir}/flightgear" \
    -DSYSTEM_SQLITE:BOOL=ON \
    -DBUILD_SHARED_LIBS:BOOL=OFF \
    -DBUILD_TESTING:BOOL=OFF \
    -DENABLE_JS_DEMO:BOOL=OFF \
    -DENABLE_GPSSMOOTH:BOOL=OFF \
    -DENABLE_FGVIEWER:BOOL=OFF \
    -DENABLE_FGELEV:BOOL=OFF \
    -DOpenGL_GL_PREFERENCE=GLVND \
    -DENABLE_METAR:BOOL=ON
%cmake_build

%install
%cmake_install
# install icons
install -m 0755 -d %{buildroot}%{_datadir}/icons/hicolor/
pushd icons
cp -r -t %{buildroot}%{_datadir}/icons/hicolor/ 16x16 32x32 48x48 64x64 128x128 scalable
popd
# install desktop file
%suse_update_desktop_file org.flightgear.FlightGear
# remove obsolete utilities
cd %{buildroot}%{_bindir} && rm -f GPSsmooth MIDGsmooth UGsmooth metar yasim yasim-proptest

%files
%doc AUTHORS ChangeLog NEWS README Thanks docs-mini/*
%license COPYING
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_mandir}/it/man1/*
%{_mandir}/it/man5/*
%{_bindir}/*
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/icons/hicolor/scalable/apps/*.svg
%{_datadir}/metainfo/org.flightgear.FlightGear.metainfo.xml
%{_datadir}/bash-completion/completions/fgfs
%{_datadir}/zsh/site-functions/_fgfs

%changelog
* Wed Mar 29 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.18
  * https://wiki.flightgear.org/Changelog_2020.3#2020.3.18
* Wed Nov 23 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.17
  * https://wiki.flightgear.org/Changelog_2020.3#2020.3.17
* Tue Apr 12 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.13
  * https://wiki.flightgear.org/Changelog_2020.3#2020.3.13
* Fri Feb  4 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.12
  * https://wiki.flightgear.org/Changelog_2020.3#2020.3.12
* Thu Aug 26 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.11
  * https://wiki.flightgear.org/Changelog_2020.3#2020.3.11
* Thu Jun 10 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.9
  * https://wiki.flightgear.org/Changelog_2020.3#2020.3.9
* Mon Apr  5 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.8
  * http://wiki.flightgear.org/Changelog_2020.3#2020.3.7
* Thu Jan 28 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.6
  * http://wiki.flightgear.org/Changelog_2020.3#2020.3.6
* Mon Jan 11 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.5
  * http://wiki.flightgear.org/Changelog_2020.3#2020.3.5
* Thu Dec 10 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.4
  * No changelog available
* Thu Nov 12 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.2
  * No changelog available
* Wed Oct 28 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.1
  * http://wiki.flightgear.org/Changelog_2020.3
- Drop upstream Fix_language_detection.patch
* Sat Jun 27 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.1.3
  * http://wiki.flightgear.org/Changelog_2020.1#2020.1.3_point_release
- Add Fix_language_detection.patch
- Use system libspeex
* Thu May 28 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.1.2
  * http://wiki.flightgear.org/Changelog_2020.1#2020.1.2_point_release
* Tue May 12 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.1.1
  * changelog: http://wiki.flightgear.org/Changelog_2020.1
* Sat May  9 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2018.3.5
  * changelog: http://wiki.flightgear.org/Changelog_2018.3#2018.3.5_point_release
- Cleaned up spec file
* Fri Aug 16 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2018.3.4
  * changelog: http://wiki.flightgear.org/Changelog_2018.3#2018.3.4_point_release
* Mon Feb 11 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2018.3.2
  * changelog: http://wiki.flightgear.org/Changelog_2018.3#2018.3.2_point_release
* Tue Dec 18 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2018.3.1
  * changelog: see upstream, http://wiki.flightgear.org/Changelog_2018.3
    and http://home.flightgear.org/news/a-preview-of-the-2018-3-release/
- Cleanup BuildRequires, add Qt5Svg
* Thu Jul 19 2018 stefan.bruens@rwth-aachen.de
- Relax FlightGear-data dependency to Recommends, data can also
  be downloaded using FGs download dialog, or e.g. using git
  checkouts, which is significantly more efficient as the
  majority of data never changes.
- Use %%license for COPYING
* Wed Jun 27 2018 Mathias.Homann@opensuse.org
- Update to 2018.2.2
  * changelog: see upstream, http://wiki.flightgear.org/Changelog_2018.2
* Fri May  4 2018 Mathias.Homann@opensuse.org
- Update to 2018.1.1
  * changelog: see upstream, http://wiki.flightgear.org/Changelog_2018.1
* Fri Jan  5 2018 rpm@fthiessen.de
- Added missing dependencies (glew, glut and udev).
* Thu Jan  4 2018 stefan.bruens@rwth-aachen.de
- Update BuildRequires:
  * pkgconfig(libcurl), no longer pulled in automatically
  * pkgconfig(dbus-1), allow screensaver inhibition
  * pkgconfig({freetype2,libpng}) for FGPanel features
- Remove deprecated Encoding key from .desktop file
* Tue Dec  5 2017 stefan.bruens@rwth-aachen.de
- BuildRequire: plib-devel, it is no longer pulled in by SimGear-devel
* Thu Nov 30 2017 qantas94heavy@gmail.com
- Remove CMAKE_BUILD_TYPE (already set by %%cmake macro)
- Standardize mixed tabs/spaces in spec file
* Thu Nov 23 2017 thorstenb@flightgear.org
- Enabled the Qt launcher interface
- Removed explicitely-link-with-libX11.patch
* Tue Sep 26 2017 Mathias.Homann@opensuse.org
- Update to 2017.3.1
  * Rename fgfs' option --log-file to --log-dir
  * Fix slow launcher diagram with bad airport data.
  * Enable —-metar runway selection.
  * Security: don't allow FGLogger to overwrite arbitrary files
  * Fix carrier starts
* Thu Mar  9 2017 wk@ire.pw.edu.pl
- Update to 2017.1.2
* Wed Jan 11 2017 rpm@fthiessen.de
- Update to 2016.4.4
- Removed upstream merged CVE-2016-9956.patch
* Fri Dec 16 2016 thorstenb@flightgear.org
- Applied patch for CVE-2016-9956 (route manager allowed to
  overwrite arbitrary files
* Sun Aug 21 2016 mailaender@opensuse.org
- Update to 2016.2.1
* Sun Mar 20 2016 bosim@opensuse.org
- Added SourceURL
* Mon Mar 14 2016 bosim@opensuse.org
- Update to 2016.1.1
* Tue Nov 24 2015 rpm@fthiessen.de
- Update to 3.7.0
- Added explicitely-link-with-libX11.patch from fedora.
* Mon Sep 23 2013 Mathias.Homann@opensuse.org
- update to 2.12.0
* Tue Mar 19 2013 joop.boonen@opensuse.org
- update to 2.10.0
* Thu Aug 23 2012 thorstenb@flightgear.org
- fix sporadic segfault when listening to ATIS (FlightGear patch
  [#5]ffbb35b)
* Fri Aug 17 2012 thorstenb@flightgear.org
- update to 2.8.0
* Thu May 24 2012 joop.boonen@opensuse.org
- Created gcc47 patch
- Cleaned the spec file up
* Fri Feb 17 2012 thorstenb@flightgear.org
- update to 2.6.0
* Tue Sep  6 2011 highwaystar.ru@gmail.com
- update to 2.4.0
- added patch to use SimGear shared libs
* Wed Apr 13 2011 Rene.vanPaassen@gmail.com
- needed to add -lplibul for openSUSE 11.4
* Tue Apr 12 2011 Rene.vanPaassen@gmail.com
- added a patch to correctly include the plib libraries
* Mon Mar  1 2010 prusnak@suse.cz
- updated to 2.0.0
- apply fixes from Fedora package by Fabrice Bellet <fabrice@bellet.info>
- split off SimGear as a separate package
* Fri Oct 16 2009 prusnak@suse.cz
- updated to 1.9.1
- cleaned spec file
* Tue Jul  1 2008 lmichnovic@suse.cz
- excluding header files in /usr/include/simgear/*
* Tue Jul  1 2008 lmichnovic@suse.cz
- fixed missing include (fgrun-missing_include.patch)
* Mon Jun 30 2008 lmichnovic@suse.cz
- added icons from Josh Babcock (GPL licensed)
- added icon name to desktop file
* Wed Apr 30 2008 lmichnovic@suse.cz
- switched to OSG viewer instead of plib
- enabled jpeg support in Simgear (libjpeg-devel -> BuildReq)
* Mon Apr 28 2008 lmichnovic@suse.cz
- update fgrun to version 1.0.1
  * program internationalized
  * dutch, french, german, italian, polish and portugese localisations
  * fix a crash when "Default" button was pressed
  * fix clock_freeze option
  * added a combo to choose bpp in the wizard
  * added aircraft status and author in the wizard
* Wed Mar  5 2008 lmichnovic@suse.cz
- added fgrun 1.0.0 application as subpackage
  needs fltk-devel in BuildReq
  It needs manual setting ;(
* Thu Jan  3 2008 lmichnovic@suse.cz
- updated FlightGear, SimGear and get_start manual to version 1.0.0
  obsoleted patches SG-include.patch, FG-includes.patch
* Wed Nov 21 2007 lmichnovic@suse.cz
- added OpenSceneGraph-devel to BuildReq
- new subpackage startup-manual which contains manual in pdf
* Tue Oct 16 2007 lmichnovic@suse.cz
- update to cvs version 20071016
- obsoletes FG patches: *64bit.patch, *test.patch
  * array_overflow.patch
- obsoletes SG: *uninitialized.patch
